macro_rules! pos {
($x:expr, $y:expr) => { ... };
}Expand description
A macro that creates a position with the given x and y coordinates.
macro_rules! pos {
($x:expr, $y:expr) => { ... };
}A macro that creates a position with the given x and y coordinates.